@@ -18,6 +18,7 @@
 #include "clutter-build-config.h"
 
 #include "clutter/clutter-stage-view.h"
+#include "clutter/clutter-stage-view-private.h"
 
 #include <cairo-gobject.h>
 #include <math.h>
@@ -61,6 +62,14 @@ clutter_stage_view_get_layout (ClutterStageView      *view,
   *rect = priv->layout;
 }
 
+/**
+ * clutter_stage_view_get_framebuffer:
+ * @view: a #ClutterStageView
+ *
+ * Retrieves the framebuffer of @view to draw to.
+ *
+ * Returns: (transfer none): a #CoglFramebuffer
+ */
 CoglFramebuffer *
 clutter_stage_view_get_framebuffer (ClutterStageView *view)
 {
@@ -73,6 +82,14 @@ clutter_stage_view_get_framebuffer (ClutterStageView *view)
     return priv->framebuffer;
 }
 
+/**
+ * clutter_stage_view_get_onscreen:
+ * @view: a #ClutterStageView
+ *
+ * Retrieves the onscreen framebuffer of @view if available.
+ *
+ * Returns: (transfer none): a #CoglFramebuffer
+ */
 CoglFramebuffer *
 clutter_stage_view_get_onscreen (ClutterStageView *view)
 {
@@ -267,7 +284,6 @@ clutter_stage_view_set_property (GObject      *object,
       priv->layout = *layout;
       break;
     case PROP_FRAMEBUFFER:
-      g_clear_pointer (&priv->framebuffer, cogl_object_unref);
       priv->framebuffer = g_value_dup_boxed (value);
 #ifndef G_DISABLE_CHECKS
       if (priv->framebuffer)
@@ -285,7 +301,6 @@ clutter_stage_view_set_property (GObject      *object,
 #endif
       break;
     case PROP_OFFSCREEN:
-      g_clear_pointer (&priv->offscreen, cogl_object_unref);
       priv->offscreen = g_value_dup_boxed (value);
       break;
     case PROP_SCALE:
@@ -357,7 +372,7 @@ clutter_stage_view_class_init (ClutterStageViewClass *klass)
                         "Framebuffer used as intermediate buffer",
                         COGL_TYPE_HANDLE,
                         G_PARAM_READWRITE |
-                        G_PARAM_CONSTRUCT |
+                        G_PARAM_CONSTRUCT_ONLY |
                         G_PARAM_STATIC_STRINGS);
 
   obj_props[PROP_SCALE] =
