@@ -74,7 +74,7 @@ cogl_primitive_new_with_attributes (CoglVerticesMode mode,
       CoglAttribute *attribute = attributes[i];
       cogl_object_ref (attribute);
 
-      _COGL_RETURN_VAL_IF_FAIL (cogl_is_attribute (attribute), NULL);
+      g_return_val_if_fail (cogl_is_attribute (attribute), NULL);
 
       primitive->attributes[i] = attribute;
     }
@@ -398,7 +398,7 @@ _cogl_primitive_free (CoglPrimitive *primitive)
 static void
 warn_about_midscene_changes (void)
 {
-  static CoglBool seen = FALSE;
+  static gboolean seen = FALSE;
   if (!seen)
     {
       g_warning ("Mid-scene modification of primitives has "
@@ -414,7 +414,7 @@ cogl_primitive_set_attributes (CoglPrimitive *primitive,
 {
   int i;
 
-  _COGL_RETURN_IF_FAIL (cogl_is_primitive (primitive));
+  g_return_if_fail (cogl_is_primitive (primitive));
 
   if (G_UNLIKELY (primitive->immutable_ref))
     {
@@ -427,7 +427,7 @@ cogl_primitive_set_attributes (CoglPrimitive *primitive,
    * attribute thats actually in the new list too. */
   for (i = 0; i < n_attributes; i++)
     {
-      _COGL_RETURN_IF_FAIL (cogl_is_attribute (attributes[i]));
+      g_return_if_fail (cogl_is_attribute (attributes[i]));
       cogl_object_ref (attributes[i]);
     }
 
@@ -463,7 +463,7 @@ cogl_primitive_set_attributes (CoglPrimitive *primitive,
 int
 cogl_primitive_get_first_vertex (CoglPrimitive *primitive)
 {
-  _COGL_RETURN_VAL_IF_FAIL (cogl_is_primitive (primitive), 0);
+  g_return_val_if_fail (cogl_is_primitive (primitive), 0);
 
   return primitive->first_vertex;
 }
@@ -472,7 +472,7 @@ void
 cogl_primitive_set_first_vertex (CoglPrimitive *primitive,
                                  int first_vertex)
 {
-  _COGL_RETURN_IF_FAIL (cogl_is_primitive (primitive));
+  g_return_if_fail (cogl_is_primitive (primitive));
 
   if (G_UNLIKELY (primitive->immutable_ref))
     {
@@ -486,7 +486,7 @@ cogl_primitive_set_first_vertex (CoglPrimitive *primitive,
 int
 cogl_primitive_get_n_vertices (CoglPrimitive *primitive)
 {
-  _COGL_RETURN_VAL_IF_FAIL (cogl_is_primitive (primitive), 0);
+  g_return_val_if_fail (cogl_is_primitive (primitive), 0);
 
   return primitive->n_vertices;
 }
@@ -495,7 +495,7 @@ void
 cogl_primitive_set_n_vertices (CoglPrimitive *primitive,
                                int n_vertices)
 {
-  _COGL_RETURN_IF_FAIL (cogl_is_primitive (primitive));
+  g_return_if_fail (cogl_is_primitive (primitive));
 
   primitive->n_vertices = n_vertices;
 }
@@ -503,7 +503,7 @@ cogl_primitive_set_n_vertices (CoglPrimitive *primitive,
 CoglVerticesMode
 cogl_primitive_get_mode (CoglPrimitive *primitive)
 {
-  _COGL_RETURN_VAL_IF_FAIL (cogl_is_primitive (primitive), 0);
+  g_return_val_if_fail (cogl_is_primitive (primitive), 0);
 
   return primitive->mode;
 }
@@ -512,7 +512,7 @@ void
 cogl_primitive_set_mode (CoglPrimitive *primitive,
                          CoglVerticesMode mode)
 {
-  _COGL_RETURN_IF_FAIL (cogl_is_primitive (primitive));
+  g_return_if_fail (cogl_is_primitive (primitive));
 
   if (G_UNLIKELY (primitive->immutable_ref))
     {
@@ -528,7 +528,7 @@ cogl_primitive_set_indices (CoglPrimitive *primitive,
                             CoglIndices *indices,
                             int n_indices)
 {
-  _COGL_RETURN_IF_FAIL (cogl_is_primitive (primitive));
+  g_return_if_fail (cogl_is_primitive (primitive));
 
   if (G_UNLIKELY (primitive->immutable_ref))
     {
@@ -571,7 +571,7 @@ _cogl_primitive_immutable_ref (CoglPrimitive *primitive)
 {
   int i;
 
-  _COGL_RETURN_VAL_IF_FAIL (cogl_is_primitive (primitive), NULL);
+  g_return_val_if_fail (cogl_is_primitive (primitive), NULL);
 
   primitive->immutable_ref++;
 
@@ -586,8 +586,8 @@ _cogl_primitive_immutable_unref (CoglPrimitive *primitive)
 {
   int i;
 
-  _COGL_RETURN_IF_FAIL (cogl_is_primitive (primitive));
-  _COGL_RETURN_IF_FAIL (primitive->immutable_ref > 0);
+  g_return_if_fail (cogl_is_primitive (primitive));
+  g_return_if_fail (primitive->immutable_ref > 0);
 
   primitive->immutable_ref--;
 
