@@ -48,11 +48,6 @@ G_BEGIN_DECLS
  * Cogl allows accessing the GL programmable pipeline in order to create
  * vertex and fragment shaders.
  *
- * The shader source code can either be GLSL or ARBfp. If the source
- * code is ARBfp, it must begin with the string “!!ARBfp1.0”. The
- * application should check for the %COGL_FEATURE_SHADERS_GLSL or
- * %COGL_FEATURE_SHADERS_ARBFP features before using shaders.
- *
  * When using GLSL Cogl provides replacement names for most of the
  * builtin varyings and uniforms. It is recommended to use these names
  * wherever possible to increase portability between OpenGL 2.0 and
@@ -234,7 +229,8 @@ G_BEGIN_DECLS
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum
+{
   COGL_SHADER_TYPE_VERTEX,
   COGL_SHADER_TYPE_FRAGMENT
 } CoglShaderType;
@@ -290,7 +286,7 @@ cogl_shader_unref (CoglHandle handle);
  * Deprecated: 1.16: Use #CoglSnippet api
  */
 COGL_DEPRECATED_FOR (cogl_snippet_)
-CoglBool
+gboolean
 cogl_is_shader (CoglHandle handle);
 
 /**
@@ -366,7 +362,7 @@ cogl_shader_get_type (CoglHandle handle);
  * Deprecated: 1.16: Use #CoglSnippet api
  */
 COGL_DEPRECATED_FOR (cogl_snippet_)
-CoglBool
+gboolean
 cogl_shader_is_compiled (CoglHandle handle);
 
 /**
@@ -421,7 +417,7 @@ cogl_program_unref (CoglHandle handle);
  * Deprecated: 1.16: Use #CoglSnippet api
  */
 COGL_DEPRECATED_FOR (cogl_snippet_)
-CoglBool
+gboolean
 cogl_is_program (CoglHandle handle);
 
 /**
@@ -605,7 +601,7 @@ cogl_program_set_uniform_matrix (CoglHandle program,
                                  int uniform_location,
                                  int dimensions,
                                  int count,
-                                 CoglBool transpose,
+                                 gboolean transpose,
                                  const float *value);
 
 /**
@@ -695,7 +691,7 @@ void
 cogl_program_uniform_matrix (int          uniform_no,
                              int          size,
                              int          count,
-                             CoglBool     transpose,
+                             gboolean     transpose,
                              const float *value);
 
 G_END_DECLS
