@@ -49,7 +49,6 @@
 #include "cogl-renderer-private.h"
 #include "cogl-object-private.h"
 #include "cogl-xlib.h"
-#include "cogl-error-private.h"
 #include "cogl-private.h"
 #include "cogl-gtype-private.h"
 #include "driver/gl/cogl-pipeline-opengl-private.h"
@@ -287,7 +286,7 @@ _cogl_texture_pixmap_x11_new (CoglContext *ctxt,
                               uint32_t pixmap,
                               gboolean automatic_updates,
                               CoglTexturePixmapStereoMode stereo_mode,
-                              CoglError **error)
+                              GError **error)
 {
   CoglTexturePixmapX11 *tex_pixmap = g_new (CoglTexturePixmapX11, 1);
   Display *display = cogl_xlib_renderer_get_display (ctxt->display->renderer);
@@ -307,10 +306,10 @@ _cogl_texture_pixmap_x11_new (CoglContext *ctxt,
                      &pixmap_border_width, &tex_pixmap->depth))
     {
       g_free (tex_pixmap);
-      _cogl_set_error (error,
-                   COGL_TEXTURE_PIXMAP_X11_ERROR,
-                   COGL_TEXTURE_PIXMAP_X11_ERROR_X11,
-                   "Unable to query pixmap size");
+      g_set_error_literal (error,
+                           COGL_TEXTURE_PIXMAP_X11_ERROR,
+                           COGL_TEXTURE_PIXMAP_X11_ERROR_X11,
+                           "Unable to query pixmap size");
       return NULL;
     }
 
@@ -339,10 +338,10 @@ _cogl_texture_pixmap_x11_new (CoglContext *ctxt,
   if (!XGetWindowAttributes (display, pixmap_root_window, &window_attributes))
     {
       g_free (tex_pixmap);
-      _cogl_set_error (error,
-                   COGL_TEXTURE_PIXMAP_X11_ERROR,
-                   COGL_TEXTURE_PIXMAP_X11_ERROR_X11,
-                   "Unable to query root window attributes");
+      g_set_error_literal (error,
+                           COGL_TEXTURE_PIXMAP_X11_ERROR,
+                           COGL_TEXTURE_PIXMAP_X11_ERROR_X11,
+                           "Unable to query root window attributes");
       return NULL;
     }
 
@@ -392,7 +391,7 @@ CoglTexturePixmapX11 *
 cogl_texture_pixmap_x11_new (CoglContext *ctxt,
                              uint32_t pixmap,
                              gboolean automatic_updates,
-                             CoglError **error)
+                             GError **error)
 
 {
   return _cogl_texture_pixmap_x11_new (ctxt, pixmap,
@@ -404,7 +403,7 @@ CoglTexturePixmapX11 *
 cogl_texture_pixmap_x11_new_left (CoglContext *ctxt,
                                   uint32_t pixmap,
                                   gboolean automatic_updates,
-                                  CoglError **error)
+                                  GError **error)
 {
   return _cogl_texture_pixmap_x11_new (ctxt, pixmap,
                                        automatic_updates, COGL_TEXTURE_PIXMAP_LEFT,
@@ -443,7 +442,7 @@ cogl_texture_pixmap_x11_new_right (CoglTexturePixmapX11 *tfp_left)
 
 static gboolean
 _cogl_texture_pixmap_x11_allocate (CoglTexture *tex,
-                                   CoglError **error)
+                                   GError **error)
 {
   return TRUE;
 }
@@ -579,7 +578,7 @@ create_fallback_texture (CoglContext *ctx,
                          CoglPixelFormat internal_format)
 {
   CoglTexture *tex;
-  CoglError *skip_error = NULL;
+  GError *skip_error = NULL;
 
   /* First try creating a fast-path non-sliced texture */
   tex = COGL_TEXTURE (cogl_texture_2d_new_with_size (ctx, width, height));
@@ -592,7 +591,7 @@ create_fallback_texture (CoglContext *ctx,
    * lazily when uploading data. */
   if (!cogl_texture_allocate (tex, &skip_error))
     {
-      cogl_error_free (skip_error);
+      g_error_free (skip_error);
       cogl_object_unref (tex);
       tex = NULL;
     }
@@ -624,7 +623,7 @@ _cogl_texture_pixmap_x11_update_image_texture (CoglTexturePixmapX11 *tex_pixmap)
   int x, y, width, height;
   int bpp;
   int offset;
-  CoglError *ignore = NULL;
+  GError *ignore = NULL;
 
   _COGL_GET_CONTEXT (ctx, NO_RETVAL);
 
@@ -846,14 +845,15 @@ _cogl_texture_pixmap_x11_set_region (CoglTexture *tex,
                                      int dst_height,
                                      int level,
                                      CoglBitmap *bmp,
-                                     CoglError **error)
+                                     GError **error)
 {
   /* This doesn't make much sense for texture from pixmap so it's not
      supported */
-  _cogl_set_error (error,
-                   COGL_SYSTEM_ERROR,
-                   COGL_SYSTEM_ERROR_UNSUPPORTED,
-                   "Explicitly setting a region of a TFP texture unsupported");
+  g_set_error_literal (error,
+                       COGL_SYSTEM_ERROR,
+                       COGL_SYSTEM_ERROR_UNSUPPORTED,
+                       "Explicitly setting a region of a TFP texture "
+                       "unsupported");
   return FALSE;
 }
 
