@@ -24,24 +24,6 @@ check_flags (TestFlags flags,
       return FALSE;
     }
 
-  if (flags & TEST_REQUIREMENT_NPOT &&
-      !cogl_has_feature (test_ctx, COGL_FEATURE_ID_TEXTURE_NPOT))
-    {
-      return FALSE;
-    }
-
-  if (flags & TEST_REQUIREMENT_TEXTURE_3D &&
-      !cogl_has_feature (test_ctx, COGL_FEATURE_ID_TEXTURE_3D))
-    {
-      return FALSE;
-    }
-
-  if (flags & TEST_REQUIREMENT_TEXTURE_RECTANGLE &&
-      !cogl_has_feature (test_ctx, COGL_FEATURE_ID_TEXTURE_RECTANGLE))
-    {
-      return FALSE;
-    }
-
   if (flags & TEST_REQUIREMENT_TEXTURE_RG &&
       !cogl_has_feature (test_ctx, COGL_FEATURE_ID_TEXTURE_RG))
     {
@@ -72,12 +54,6 @@ check_flags (TestFlags flags,
       return FALSE;
     }
 
-  if (flags & TEST_REQUIREMENT_GLSL &&
-      !cogl_has_feature (test_ctx, COGL_FEATURE_ID_GLSL))
-    {
-      return FALSE;
-    }
-
   if (flags & TEST_REQUIREMENT_OFFSCREEN &&
       !cogl_has_feature (test_ctx, COGL_FEATURE_ID_OFFSCREEN))
     {
@@ -130,7 +106,7 @@ test_utils_init (TestFlags requirement_flags,
                  TestFlags known_failure_flags)
 {
   static int counter = 0;
-  CoglError *error = NULL;
+  GError *error = NULL;
   CoglOnscreen *onscreen = NULL;
   CoglDisplay *display;
   CoglRenderer *renderer;
@@ -371,27 +347,19 @@ test_utils_texture_new_with_size (CoglContext *ctx,
                                   CoglTextureComponents components)
 {
   CoglTexture *tex;
-  CoglError *skip_error = NULL;
+  GError *skip_error = NULL;
 
-  if ((test_utils_is_pot (width) && test_utils_is_pot (height)) ||
-      (cogl_has_feature (ctx, COGL_FEATURE_ID_TEXTURE_NPOT_BASIC) &&
-       cogl_has_feature (ctx, COGL_FEATURE_ID_TEXTURE_NPOT_MIPMAP)))
+  /* First try creating a fast-path non-sliced texture */
+  tex = COGL_TEXTURE (cogl_texture_2d_new_with_size (ctx, width, height));
+
+  cogl_texture_set_components (tex, components);
+
+  if (!cogl_texture_allocate (tex, &skip_error))
     {
-      /* First try creating a fast-path non-sliced texture */
-      tex = COGL_TEXTURE (cogl_texture_2d_new_with_size (ctx,
-                                                         width, height));
-
-      cogl_texture_set_components (tex, components);
-
-      if (!cogl_texture_allocate (tex, &skip_error))
-        {
-          cogl_error_free (skip_error);
-          cogl_object_unref (tex);
-          tex = NULL;
-        }
+      g_error_free (skip_error);
+      cogl_object_unref (tex);
+      tex = NULL;
     }
-  else
-    tex = NULL;
 
   if (!tex)
     {
@@ -434,7 +402,7 @@ test_utils_texture_new_from_bitmap (CoglBitmap *bitmap,
 {
   CoglAtlasTexture *atlas_tex;
   CoglTexture *tex;
-  CoglError *internal_error = NULL;
+  GError *internal_error = NULL;
 
   if (!flags)
     {
@@ -446,37 +414,25 @@ test_utils_texture_new_from_bitmap (CoglBitmap *bitmap,
       if (cogl_texture_allocate (COGL_TEXTURE (atlas_tex), &internal_error))
         return COGL_TEXTURE (atlas_tex);
 
-      cogl_error_free (internal_error);
       cogl_object_unref (atlas_tex);
-      internal_error = NULL;
     }
 
+  g_clear_error (&internal_error);
+
   /* If that doesn't work try a fast path 2D texture */
-  if ((test_utils_is_pot (cogl_bitmap_get_width (bitmap)) &&
-       test_utils_is_pot (cogl_bitmap_get_height (bitmap))) ||
-      (cogl_has_feature (test_ctx, COGL_FEATURE_ID_TEXTURE_NPOT_BASIC) &&
-       cogl_has_feature (test_ctx, COGL_FEATURE_ID_TEXTURE_NPOT_MIPMAP)))
+  tex = COGL_TEXTURE (cogl_texture_2d_new_from_bitmap (bitmap));
+
+  cogl_texture_set_premultiplied (tex, premultiplied);
+
+  if (g_error_matches (internal_error,
+                       COGL_SYSTEM_ERROR,
+                       COGL_SYSTEM_ERROR_NO_MEMORY))
     {
-      tex = COGL_TEXTURE (cogl_texture_2d_new_from_bitmap (bitmap));
-
-      cogl_texture_set_premultiplied (tex, premultiplied);
-
-      if (cogl_error_matches (internal_error,
-                              COGL_SYSTEM_ERROR,
-                              COGL_SYSTEM_ERROR_NO_MEMORY))
-        {
-          g_assert_not_reached ();
-          return NULL;
-        }
-
-      if (!tex)
-        {
-          cogl_error_free (internal_error);
-          internal_error = NULL;
-        }
+      g_assert_not_reached ();
+      return NULL;
     }
-  else
-    tex = NULL;
+
+  g_clear_error (&internal_error);
 
   if (!tex)
     {
