@@ -31,7 +31,6 @@
 #include "backends/meta-dbus-session-watcher.h"
 #include "backends/meta-screen-cast-session.h"
 #include "backends/meta-remote-access-controller-private.h"
-#include "backends/native/meta-backend-native.h"
 #include "backends/x11/meta-backend-x11.h"
 #include "cogl/cogl.h"
 #include "meta/meta-backend.h"
@@ -479,6 +478,7 @@ discrete_steps_to_scroll_direction (unsigned int axis,
     return CLUTTER_SCROLL_RIGHT;
 
   g_assert_not_reached ();
+  return 0;
 }
 
 static gboolean
