@@ -24,6 +24,7 @@
 #include <stdint.h>
 #include <glib-object.h>
 
+#include "backends/meta-cursor.h"
 #include "meta/boxes.h"
 
 G_BEGIN_DECLS
@@ -36,9 +37,6 @@ struct _MetaScreenCastWindowInterface
 {
   GTypeInterface parent_iface;
 
-  void (*get_buffer_bounds) (MetaScreenCastWindow *screen_cast_window,
-                             MetaRectangle        *bounds);
-
   void (*get_frame_bounds) (MetaScreenCastWindow *screen_cast_window,
                             MetaRectangle        *bounds);
 
@@ -48,13 +46,18 @@ struct _MetaScreenCastWindowInterface
                                        double               *x_out,
                                        double               *y_out);
 
+  gboolean (*transform_cursor_position) (MetaScreenCastWindow *screen_cast_window,
+                                         MetaCursorSprite     *cursor_sprite,
+                                         ClutterPoint         *cursor_position,
+                                         float                *out_cursor_scale,
+                                         ClutterPoint         *out_relative_cursor_position);
+
   void (*capture_into) (MetaScreenCastWindow *screen_cast_window,
                         MetaRectangle        *bounds,
                         uint8_t              *data);
-};
 
-void meta_screen_cast_window_get_buffer_bounds (MetaScreenCastWindow *screen_cast_window,
-                                                MetaRectangle        *bounds);
+  gboolean (*has_damage) (MetaScreenCastWindow *screen_cast_window);
+};
 
 void meta_screen_cast_window_get_frame_bounds (MetaScreenCastWindow *screen_cast_window,
                                                MetaRectangle        *bounds);
@@ -65,10 +68,18 @@ void meta_screen_cast_window_transform_relative_position (MetaScreenCastWindow *
                                                           double               *x_out,
                                                           double               *y_out);
 
+gboolean meta_screen_cast_window_transform_cursor_position (MetaScreenCastWindow *screen_cast_window,
+                                                            MetaCursorSprite     *cursor_sprite,
+                                                            ClutterPoint         *cursor_position,
+                                                            float                *out_cursor_scale,
+                                                            ClutterPoint         *out_relative_cursor_position);
+
 void meta_screen_cast_window_capture_into (MetaScreenCastWindow *screen_cast_window,
                                            MetaRectangle        *bounds,
                                            uint8_t              *data);
 
+gboolean meta_screen_cast_window_has_damage (MetaScreenCastWindow *screen_cast_window);
+
 G_END_DECLS
 
 #endif /* META_SCREEN_CAST_WINDOW_H */
