@@ -51,6 +51,8 @@
 #include "backends/native/meta-clutter-backend-native.h"
 #include "backends/native/meta-cursor-renderer-native.h"
 #include "backends/native/meta-input-settings-native.h"
+#include "backends/native/meta-kms.h"
+#include "backends/native/meta-kms-device.h"
 #include "backends/native/meta-launcher.h"
 #include "backends/native/meta-monitor-manager-kms.h"
 #include "backends/native/meta-renderer-native.h"
@@ -62,14 +64,14 @@
 struct _MetaBackendNative
 {
   MetaBackend parent;
-};
 
-struct _MetaBackendNativePrivate
-{
   MetaLauncher *launcher;
+  MetaUdev *udev;
+  MetaKms *kms;
   MetaBarrierManagerNative *barrier_manager;
+
+  guint udev_device_added_handler_id;
 };
-typedef struct _MetaBackendNativePrivate MetaBackendNativePrivate;
 
 static GInitableIface *initable_parent_iface;
 
@@ -77,17 +79,23 @@ static void
 initable_iface_init (GInitableIface *initable_iface);
 
 G_DEFINE_TYPE_WITH_CODE (MetaBackendNative, meta_backend_native, META_TYPE_BACKEND,
-                         G_ADD_PRIVATE (MetaBackendNative)
                          G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                 initable_iface_init))
 
+static void
+disconnect_udev_device_added_handler (MetaBackendNative *native);
+
 static void
 meta_backend_native_finalize (GObject *object)
 {
   MetaBackendNative *native = META_BACKEND_NATIVE (object);
-  MetaBackendNativePrivate *priv = meta_backend_native_get_instance_private (native);
 
-  meta_launcher_free (priv->launcher);
+  if (native->udev_device_added_handler_id)
+    disconnect_udev_device_added_handler (native);
+
+  g_clear_object (&native->udev);
+  g_clear_object (&native->kms);
+  meta_launcher_free (native->launcher);
 
   G_OBJECT_CLASS (meta_backend_native_parent_class)->finalize (object);
 }
@@ -99,10 +107,8 @@ constrain_to_barriers (ClutterInputDevice *device,
                        float              *new_y)
 {
   MetaBackendNative *native = META_BACKEND_NATIVE (meta_get_backend ());
-  MetaBackendNativePrivate *priv =
-    meta_backend_native_get_instance_private (native);
 
-  meta_barrier_manager_native_process (priv->barrier_manager,
+  meta_barrier_manager_native_process (native->barrier_manager,
                                        device,
                                        time,
                                        new_x, new_y);
@@ -376,13 +382,10 @@ static MetaRenderer *
 meta_backend_native_create_renderer (MetaBackend *backend,
                                      GError     **error)
 {
-  MetaMonitorManager *monitor_manager =
-    meta_backend_get_monitor_manager (backend);
-  MetaMonitorManagerKms *monitor_manager_kms =
-    META_MONITOR_MANAGER_KMS (monitor_manager);
+  MetaBackendNative *native = META_BACKEND_NATIVE (backend);
   MetaRendererNative *renderer_native;
 
-  renderer_native = meta_renderer_native_new (monitor_manager_kms, error);
+  renderer_native = meta_renderer_native_new (native, error);
   if (!renderer_native)
     return NULL;
 
@@ -519,11 +522,142 @@ meta_backend_native_update_screen_size (MetaBackend *backend,
   clutter_actor_set_size (stage, width, height);
 }
 
+static MetaGpuKms *
+create_gpu_from_udev_device (MetaBackendNative  *native,
+                             GUdevDevice        *device,
+                             GError            **error)
+{
+  MetaKmsDeviceFlag flags = META_KMS_DEVICE_FLAG_NONE;
+  const char *device_path;
+  MetaKmsDevice *kms_device;
+
+  if (meta_is_udev_device_platform_device (device))
+    flags |= META_KMS_DEVICE_FLAG_PLATFORM_DEVICE;
+
+  if (meta_is_udev_device_boot_vga (device))
+    flags |= META_KMS_DEVICE_FLAG_BOOT_VGA;
+
+  device_path = g_udev_device_get_device_file (device);
+
+  kms_device = meta_kms_create_device (native->kms, device_path, flags,
+                                       error);
+  if (!kms_device)
+    return NULL;
+
+  return meta_gpu_kms_new (native, kms_device, error);
+}
+
+static void
+on_udev_device_added (MetaUdev          *udev,
+                      GUdevDevice       *device,
+                      MetaBackendNative *native)
+{
+  MetaBackend *backend = META_BACKEND (native);
+  g_autoptr (GError) error = NULL;
+  const char *device_path;
+  MetaGpuKms *new_gpu_kms;
+  GList *gpus, *l;
+
+  if (!meta_udev_is_drm_device (udev, device))
+    return;
+
+  device_path = g_udev_device_get_device_file (device);
+
+  gpus = meta_backend_get_gpus (backend);;
+  for (l = gpus; l; l = l->next)
+    {
+      MetaGpuKms *gpu_kms = l->data;
+
+      if (!g_strcmp0 (device_path, meta_gpu_kms_get_file_path (gpu_kms)))
+        {
+          g_warning ("Failed to hotplug secondary gpu '%s': %s",
+                     device_path, "device already present");
+          return;
+        }
+    }
+
+  new_gpu_kms = create_gpu_from_udev_device (native, device, &error);
+  if (!new_gpu_kms)
+    {
+      g_warning ("Failed to hotplug secondary gpu '%s': %s",
+                 device_path, error->message);
+      g_error_free (error);
+      return;
+    }
+
+  meta_backend_add_gpu (backend, META_GPU (new_gpu_kms));
+}
+
+static void
+connect_udev_device_added_handler (MetaBackendNative *native)
+{
+  native->udev_device_added_handler_id =
+    g_signal_connect (native->udev, "device-added",
+                      G_CALLBACK (on_udev_device_added), native);
+}
+
+static void
+disconnect_udev_device_added_handler (MetaBackendNative *native)
+{
+  g_signal_handler_disconnect (native->udev,
+                               native->udev_device_added_handler_id);
+  native->udev_device_added_handler_id = 0;
+}
+
+static gboolean
+init_gpus (MetaBackendNative  *native,
+           GError            **error)
+{
+  MetaBackend *backend = META_BACKEND (native);
+  MetaUdev *udev = meta_backend_native_get_udev (native);
+  GList *devices;
+  GList *l;
+
+  devices = meta_udev_list_drm_devices (udev, error);
+  if (!devices)
+    return FALSE;
+
+  for (l = devices; l; l = l->next)
+    {
+      GUdevDevice *device = l->data;
+      MetaGpuKms *gpu_kms;
+      GError *local_error = NULL;
+
+      gpu_kms = create_gpu_from_udev_device (native, device, &local_error);
+
+      if (!gpu_kms)
+        {
+          g_warning ("Failed to open gpu '%s': %s",
+                     g_udev_device_get_device_file (device),
+                     local_error->message);
+          g_clear_error (&local_error);
+          continue;
+        }
+
+      meta_backend_add_gpu (backend, META_GPU (gpu_kms));
+    }
+
+  g_list_free_full (devices, g_object_unref);
+
+  if (g_list_length (meta_backend_get_gpus (backend)) == 0)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
+                   "No GPUs found");
+      return FALSE;
+    }
+
+  connect_udev_device_added_handler (native);
+
+  return TRUE;
+}
+
 static gboolean
 meta_backend_native_initable_init (GInitable     *initable,
                                    GCancellable  *cancellable,
                                    GError       **error)
 {
+  MetaBackendNative *native = META_BACKEND_NATIVE (initable);
+
   if (!meta_is_stage_views_enabled ())
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
@@ -531,6 +665,20 @@ meta_backend_native_initable_init (GInitable     *initable,
       return FALSE;
     }
 
+  native->launcher = meta_launcher_new (error);
+  if (!native->launcher)
+    return FALSE;
+
+  native->udev = meta_udev_new (native);
+  native->barrier_manager = meta_barrier_manager_native_new ();
+
+  native->kms = meta_kms_new (META_BACKEND (native), error);
+  if (!native->kms)
+    return FALSE;
+
+  if (!init_gpus (native, error))
+    return FALSE;
+
   return initable_parent_iface->init (initable, cancellable, error);
 }
 
@@ -575,26 +723,24 @@ meta_backend_native_class_init (MetaBackendNativeClass *klass)
 static void
 meta_backend_native_init (MetaBackendNative *native)
 {
-  MetaBackendNativePrivate *priv = meta_backend_native_get_instance_private (native);
-  GError *error = NULL;
-
-  priv->launcher = meta_launcher_new (&error);
-  if (priv->launcher == NULL)
-    {
-      g_warning ("Can't initialize KMS backend: %s\n", error->message);
-      exit (1);
-    }
-
-  priv->barrier_manager = meta_barrier_manager_native_new ();
 }
 
 MetaLauncher *
 meta_backend_native_get_launcher (MetaBackendNative *native)
 {
-  MetaBackendNativePrivate *priv =
-    meta_backend_native_get_instance_private (native);
+  return native->launcher;
+}
 
-  return priv->launcher;
+MetaUdev *
+meta_backend_native_get_udev (MetaBackendNative *native)
+{
+  return native->udev;
+}
+
+MetaKms *
+meta_backend_native_get_kms (MetaBackendNative *native)
+{
+  return native->kms;
 }
 
 gboolean
@@ -610,10 +756,7 @@ meta_activate_vt (int vt, GError **error)
 MetaBarrierManagerNative *
 meta_backend_native_get_barrier_manager (MetaBackendNative *native)
 {
-  MetaBackendNativePrivate *priv =
-    meta_backend_native_get_instance_private (native);
-
-  return priv->barrier_manager;
+  return native->barrier_manager;
 }
 
 /**
@@ -634,9 +777,8 @@ meta_activate_session (void)
     return TRUE;
 
   MetaBackendNative *native = META_BACKEND_NATIVE (backend);
-  MetaBackendNativePrivate *priv = meta_backend_native_get_instance_private (native);
 
-  if (!meta_launcher_activate_session (priv->launcher, &error))
+  if (!meta_launcher_activate_session (native->launcher, &error))
     {
       g_warning ("Could not activate session: %s\n", error->message);
       g_error_free (error);
@@ -659,6 +801,8 @@ meta_backend_native_pause (MetaBackendNative *native)
   clutter_evdev_release_devices ();
   clutter_stage_freeze_updates (stage);
 
+  disconnect_udev_device_added_handler (native);
+
   meta_monitor_manager_kms_pause (monitor_manager_kms);
 }
 
@@ -670,10 +814,13 @@ void meta_backend_native_resume (MetaBackendNative *native)
     meta_backend_get_monitor_manager (backend);
   MetaMonitorManagerKms *monitor_manager_kms =
     META_MONITOR_MANAGER_KMS (monitor_manager);
+  MetaInputSettings *input_settings;
   MetaIdleMonitor *idle_monitor;
 
   meta_monitor_manager_kms_resume (monitor_manager_kms);
 
+  connect_udev_device_added_handler (native);
+
   clutter_evdev_reclaim_devices ();
   clutter_stage_thaw_updates (stage);
 
@@ -681,4 +828,7 @@ void meta_backend_native_resume (MetaBackendNative *native)
 
   idle_monitor = meta_backend_get_idle_monitor (backend, 0);
   meta_idle_monitor_reset_idletime (idle_monitor);
+
+  input_settings = meta_backend_get_input_settings (backend);
+  meta_input_settings_maybe_restore_numlock_state (input_settings);
 }
