@@ -28,39 +28,17 @@
 #include <xf86drmMode.h>
 
 #include "backends/meta-gpu.h"
-#include "backends/native/meta-monitor-manager-kms.h"
+#include "backends/native/meta-backend-native.h"
+#include "backends/native/meta-kms-types.h"
 
 #define META_TYPE_GPU_KMS (meta_gpu_kms_get_type ())
 G_DECLARE_FINAL_TYPE (MetaGpuKms, meta_gpu_kms, META, GPU_KMS, MetaGpu)
 
 typedef struct _MetaGpuKmsFlipClosureContainer MetaGpuKmsFlipClosureContainer;
 
-typedef struct _MetaKmsResources
-{
-  drmModeRes *resources;
-  drmModeEncoder **encoders;
-  unsigned int n_encoders;
-} MetaKmsResources;
-
-typedef void (*MetaKmsFlipCallback) (void *user_data);
-
-typedef enum _MetaGpuKmsFlag
-{
-  META_GPU_KMS_FLAG_NONE =                  0,
-  META_GPU_KMS_FLAG_BOOT_VGA =        (1 << 0),
-  META_GPU_KMS_FLAG_PLATFORM_DEVICE = (1 << 1),
-} MetaGpuKmsFlag;
-
-MetaGpuKms * meta_gpu_kms_new (MetaMonitorManagerKms  *monitor_manager_kms,
-                               const char             *kms_file_path,
-                               MetaGpuKmsFlag          flags,
-                               GError                **error);
-
-gboolean meta_gpu_kms_apply_crtc_mode (MetaGpuKms *gpu_kms,
-                                       MetaCrtc   *crtc,
-                                       int         x,
-                                       int         y,
-                                       uint32_t    fb_id);
+MetaGpuKms * meta_gpu_kms_new (MetaBackendNative  *backend_native,
+                               MetaKmsDevice      *kms_device,
+                               GError            **error);
 
 gboolean meta_gpu_kms_can_have_outputs (MetaGpuKms *gpu_kms);
 
@@ -70,17 +48,11 @@ gboolean meta_gpu_kms_is_crtc_active (MetaGpuKms *gpu_kms,
 gboolean meta_gpu_kms_is_boot_vga (MetaGpuKms *gpu_kms);
 gboolean meta_gpu_kms_is_platform_device (MetaGpuKms *gpu_kms);
 
-gboolean meta_gpu_kms_flip_crtc (MetaGpuKms *gpu_kms,
-                                 MetaCrtc   *crtc,
-                                 int         x,
-                                 int         y,
-                                 uint32_t    fb_id,
-                                 GClosure   *flip_closure,
-                                 gboolean   *fb_in_use);
-
 gboolean meta_gpu_kms_wait_for_flip (MetaGpuKms *gpu_kms,
                                      GError    **error);
 
+MetaKmsDevice * meta_gpu_kms_get_kms_device (MetaGpuKms *gpu_kms);
+
 int meta_gpu_kms_get_fd (MetaGpuKms *gpu_kms);
 
 uint32_t meta_gpu_kms_get_id (MetaGpuKms *gpu_kms);
@@ -89,12 +61,9 @@ const char * meta_gpu_kms_get_file_path (MetaGpuKms *gpu_kms);
 
 int64_t meta_gpu_kms_get_current_time_ns (MetaGpuKms *gpu_kms);
 
-void meta_gpu_kms_get_max_buffer_size (MetaGpuKms *gpu_kms,
-                                       int        *max_width,
-                                       int        *max_height);
-
-void meta_gpu_kms_set_power_save_mode (MetaGpuKms *gpu_kms,
-                                       uint64_t    state);
+void meta_gpu_kms_set_power_save_mode (MetaGpuKms    *gpu_kms,
+                                       uint64_t       state,
+                                       MetaKmsUpdate *kms_update);
 
 MetaCrtcMode * meta_gpu_kms_get_mode_from_drm_mode (MetaGpuKms            *gpu_kms,
                                                     const drmModeModeInfo *drm_mode);
@@ -102,8 +71,6 @@ MetaCrtcMode * meta_gpu_kms_get_mode_from_drm_mode (MetaGpuKms            *gpu_k
 gboolean meta_drm_mode_equal (const drmModeModeInfo *one,
                               const drmModeModeInfo *two);
 
-float meta_calculate_drm_mode_refresh_rate (const drmModeModeInfo *mode);
-
 MetaGpuKmsFlipClosureContainer * meta_gpu_kms_wrap_flip_closure (MetaGpuKms *gpu_kms,
                                                                  MetaCrtc   *crtc,
                                                                  GClosure   *flip_closure);
