@@ -73,13 +73,6 @@ struct _MetaMonitorManagerXrandr
   int rr_error_base;
   gboolean has_randr15;
 
-  /*
-   * The X server deals with multiple GPUs for us, soe just see what the X
-   * server gives us as one single GPU, even though it may actually be backed
-   * by multiple.
-   */
-  MetaGpu *gpu;
-
   xcb_timestamp_t last_xrandr_set_timestamp;
 
   GHashTable *tiled_monitor_atoms;
@@ -121,6 +114,50 @@ meta_monitor_manager_xrandr_read_edid (MetaMonitorManager *manager,
   return meta_output_xrandr_read_edid (output);
 }
 
+static MetaPowerSave
+x11_dpms_state_to_power_save (CARD16 dpms_state)
+{
+  switch (dpms_state)
+    {
+    case DPMSModeOn:
+      return META_POWER_SAVE_ON;
+    case DPMSModeStandby:
+      return META_POWER_SAVE_STANDBY;
+    case DPMSModeSuspend:
+      return META_POWER_SAVE_SUSPEND;
+    case DPMSModeOff:
+      return META_POWER_SAVE_OFF;
+    default:
+      return META_POWER_SAVE_UNSUPPORTED;
+    }
+}
+
+static void
+meta_monitor_manager_xrandr_read_current_state (MetaMonitorManager *manager)
+{
+  MetaMonitorManagerXrandr *manager_xrandr =
+    META_MONITOR_MANAGER_XRANDR (manager);
+  MetaMonitorManagerClass *parent_class =
+    META_MONITOR_MANAGER_CLASS (meta_monitor_manager_xrandr_parent_class);
+  Display *xdisplay = meta_monitor_manager_xrandr_get_xdisplay (manager_xrandr);
+  BOOL dpms_capable, dpms_enabled;
+  CARD16 dpms_state;
+  MetaPowerSave power_save_mode;
+
+  dpms_capable = DPMSCapable (xdisplay);
+
+  if (dpms_capable &&
+      DPMSInfo (xdisplay, &dpms_state, &dpms_enabled) &&
+      dpms_enabled)
+    power_save_mode = x11_dpms_state_to_power_save (dpms_state);
+  else
+    power_save_mode = META_POWER_SAVE_UNSUPPORTED;
+
+  meta_monitor_manager_power_save_mode_changed (manager, power_save_mode);
+
+  parent_class->read_current_state (manager);
+}
+
 static void
 meta_monitor_manager_xrandr_set_power_save_mode (MetaMonitorManager *manager,
 						 MetaPowerSave       mode)
@@ -300,6 +337,15 @@ is_output_assignment_changed (MetaOutput      *output,
   return TRUE;
 }
 
+static MetaGpu *
+meta_monitor_manager_xrandr_get_gpu (MetaMonitorManagerXrandr *manager_xrandr)
+{
+  MetaMonitorManager *manager = META_MONITOR_MANAGER (manager_xrandr);
+  MetaBackend *backend = meta_monitor_manager_get_backend (manager);
+
+  return META_GPU (meta_backend_get_gpus (backend)->data);
+}
+
 static gboolean
 is_assignments_changed (MetaMonitorManager *manager,
                         MetaCrtcInfo      **crtc_infos,
@@ -309,9 +355,10 @@ is_assignments_changed (MetaMonitorManager *manager,
 {
   MetaMonitorManagerXrandr *manager_xrandr =
     META_MONITOR_MANAGER_XRANDR (manager);
+  MetaGpu *gpu = meta_monitor_manager_xrandr_get_gpu (manager_xrandr);
   GList *l;
 
-  for (l = meta_gpu_get_crtcs (manager_xrandr->gpu); l; l = l->next)
+  for (l = meta_gpu_get_crtcs (gpu); l; l = l->next)
     {
       MetaCrtc *crtc = l->data;
 
@@ -319,7 +366,7 @@ is_assignments_changed (MetaMonitorManager *manager,
         return TRUE;
     }
 
-  for (l = meta_gpu_get_outputs (manager_xrandr->gpu); l; l = l->next)
+  for (l = meta_gpu_get_outputs (gpu); l; l = l->next)
     {
       MetaOutput *output = l->data;
 
@@ -343,6 +390,7 @@ apply_crtc_assignments (MetaMonitorManager *manager,
                         unsigned int        n_outputs)
 {
   MetaMonitorManagerXrandr *manager_xrandr = META_MONITOR_MANAGER_XRANDR (manager);
+  MetaGpu *gpu = meta_monitor_manager_xrandr_get_gpu (manager_xrandr);
   unsigned i;
   GList *l;
   int width, height, width_mm, height_mm;
@@ -404,7 +452,7 @@ apply_crtc_assignments (MetaMonitorManager *manager,
     }
 
   /* Disable CRTCs not mentioned in the list */
-  for (l = meta_gpu_get_crtcs (manager_xrandr->gpu); l; l = l->next)
+  for (l = meta_gpu_get_crtcs (gpu); l; l = l->next)
     {
       MetaCrtc *crtc = l->data;
 
@@ -524,7 +572,7 @@ apply_crtc_assignments (MetaMonitorManager *manager,
     }
 
   /* Disable outputs not mentioned in the list */
-  for (l = meta_gpu_get_outputs (manager_xrandr->gpu); l; l = l->next)
+  for (l = meta_gpu_get_outputs (gpu); l; l = l->next)
     {
       MetaOutput *output = l->data;
 
@@ -929,11 +977,11 @@ ensure_supported_monitor_scales (MetaMonitorManager *manager)
 }
 
 static float *
-meta_monitor_manager_xrandr_calculate_supported_scales (MetaMonitorManager          *manager,
-                                                        MetaLogicalMonitorLayoutMode layout_mode,
-                                                        MetaMonitor                 *monitor,
-                                                        MetaMonitorMode             *monitor_mode,
-                                                        int                         *n_supported_scales)
+meta_monitor_manager_xrandr_calculate_supported_scales (MetaMonitorManager           *manager,
+                                                        MetaLogicalMonitorLayoutMode  layout_mode,
+                                                        MetaMonitor                  *monitor,
+                                                        MetaMonitorMode              *monitor_mode,
+                                                        int                          *n_supported_scales)
 {
   MetaMonitorManagerXrandr *manager_xrandr =
     META_MONITOR_MANAGER_XRANDR (manager);
@@ -959,8 +1007,9 @@ meta_monitor_manager_xrandr_get_max_screen_size (MetaMonitorManager *manager,
 {
   MetaMonitorManagerXrandr *manager_xrandr =
     META_MONITOR_MANAGER_XRANDR (manager);
+  MetaGpu *gpu = meta_monitor_manager_xrandr_get_gpu (manager_xrandr);
 
-  meta_gpu_xrandr_get_max_screen_size (META_GPU_XRANDR (manager_xrandr->gpu),
+  meta_gpu_xrandr_get_max_screen_size (META_GPU_XRANDR (gpu),
                                        max_width, max_height);
 
   return TRUE;
@@ -978,13 +1027,10 @@ meta_monitor_manager_xrandr_constructed (GObject *object)
   MetaMonitorManagerXrandr *manager_xrandr =
     META_MONITOR_MANAGER_XRANDR (object);
   MetaMonitorManager *manager = META_MONITOR_MANAGER (manager_xrandr);
-  MetaBackendX11 *backend =
-    META_BACKEND_X11 (meta_monitor_manager_get_backend (manager));
+  MetaBackend *backend = meta_monitor_manager_get_backend (manager);
+  MetaBackendX11 *backend_x11 = META_BACKEND_X11 (backend);
 
-  manager_xrandr->xdisplay = meta_backend_x11_get_xdisplay (backend);
-
-  manager_xrandr->gpu = META_GPU (meta_gpu_xrandr_new (manager_xrandr));
-  meta_monitor_manager_add_gpu (manager, manager_xrandr->gpu);
+  manager_xrandr->xdisplay = meta_backend_x11_get_xdisplay (backend_x11);
 
   if (!XRRQueryExtension (manager_xrandr->xdisplay,
 			  &manager_xrandr->rr_event_base,
@@ -1024,7 +1070,6 @@ meta_monitor_manager_xrandr_finalize (GObject *object)
 {
   MetaMonitorManagerXrandr *manager_xrandr = META_MONITOR_MANAGER_XRANDR (object);
 
-  g_clear_object (&manager_xrandr->gpu);
   g_hash_table_destroy (manager_xrandr->tiled_monitor_atoms);
   g_free (manager_xrandr->supported_scales);
 
@@ -1046,6 +1091,7 @@ meta_monitor_manager_xrandr_class_init (MetaMonitorManagerXrandrClass *klass)
   object_class->constructed = meta_monitor_manager_xrandr_constructed;
 
   manager_class->read_edid = meta_monitor_manager_xrandr_read_edid;
+  manager_class->read_current_state = meta_monitor_manager_xrandr_read_current_state;
   manager_class->ensure_initial_config = meta_monitor_manager_xrandr_ensure_initial_config;
   manager_class->apply_monitors_config = meta_monitor_manager_xrandr_apply_monitors_config;
   manager_class->set_power_save_mode = meta_monitor_manager_xrandr_set_power_save_mode;
@@ -1070,6 +1116,7 @@ meta_monitor_manager_xrandr_handle_xevent (MetaMonitorManagerXrandr *manager_xra
 					   XEvent                   *event)
 {
   MetaMonitorManager *manager = META_MONITOR_MANAGER (manager_xrandr);
+  MetaGpu *gpu = meta_monitor_manager_xrandr_get_gpu (manager_xrandr);
   MetaGpuXrandr *gpu_xrandr;
   XRRScreenResources *resources;
   gboolean is_hotplug;
@@ -1082,7 +1129,7 @@ meta_monitor_manager_xrandr_handle_xevent (MetaMonitorManagerXrandr *manager_xra
 
   meta_monitor_manager_read_current_state (manager);
 
-  gpu_xrandr = META_GPU_XRANDR (manager_xrandr->gpu);
+  gpu_xrandr = META_GPU_XRANDR (gpu);
   resources = meta_gpu_xrandr_get_resources (gpu_xrandr);
 
   is_hotplug = resources->timestamp < resources->configTimestamp;
