@@ -299,9 +299,9 @@ meta_plugin_manager_confirm_display_change (MetaPluginManager *plugin_mgr)
   MetaPluginClass *klass = META_PLUGIN_GET_CLASS (plugin);
 
   if (klass->confirm_display_change)
-    return klass->confirm_display_change (plugin);
+    klass->confirm_display_change (plugin);
   else
-    return meta_plugin_complete_display_change (plugin, TRUE);
+    meta_plugin_complete_display_change (plugin, TRUE);
 }
 
 gboolean
@@ -405,3 +405,13 @@ meta_plugin_manager_create_inhibit_shortcuts_dialog (MetaPluginManager *plugin_m
 
   return meta_inhibit_shortcuts_dialog_default_new (window);
 }
+
+void
+meta_plugin_manager_locate_pointer (MetaPluginManager *plugin_mgr)
+{
+  MetaPlugin *plugin = plugin_mgr->plugin;
+  MetaPluginClass *klass = META_PLUGIN_GET_CLASS (plugin);
+
+  if (klass->locate_pointer)
+    klass->locate_pointer (plugin);
+}
