@@ -106,11 +106,6 @@ struct _MetaShadowFactory
   GHashTable *shadow_classes;
 };
 
-struct _MetaShadowFactoryClass
-{
-  GObjectClass parent_class;
-};
-
 enum
 {
   CHANGED,
@@ -133,7 +128,7 @@ MetaShadowClassInfo default_shadow_classes[] = {
   { "popup-menu",    { 1, -1, 0, 0, 128 }, { 1, -1, 0, 0, 128 } },
   { "dropdown-menu", { 1, -1, 0, 0, 128 }, { 1, -1, 0, 0, 128 } },
 
-  { "attached",      { 0, -1, 0, 0, 0 }, { 0, -1, 0, 0, 0 } }
+  { "attached",      { 10, -1, 0, 3, 128 }, { 8, -1, 0, 2, 64 } }
 };
 
 G_DEFINE_TYPE (MetaShadowFactory, meta_shadow_factory, G_TYPE_OBJECT);
@@ -203,14 +198,15 @@ meta_shadow_unref (MetaShadow *shadow)
  * size needs to be passed in here.)
  */
 void
-meta_shadow_paint (MetaShadow     *shadow,
-                   int             window_x,
-                   int             window_y,
-                   int             window_width,
-                   int             window_height,
-                   guint8          opacity,
-                   cairo_region_t *clip,
-                   gboolean        clip_strictly)
+meta_shadow_paint (MetaShadow      *shadow,
+                   CoglFramebuffer *framebuffer,
+                   int              window_x,
+                   int              window_y,
+                   int              window_width,
+                   int              window_height,
+                   guint8           opacity,
+                   cairo_region_t  *clip,
+                   gboolean         clip_strictly)
 {
   float texture_width = cogl_texture_get_width (shadow->texture);
   float texture_height = cogl_texture_get_height (shadow->texture);
@@ -220,11 +216,7 @@ meta_shadow_paint (MetaShadow     *shadow,
   int dest_x[4];
   int dest_y[4];
   int n_x, n_y;
-
-  cogl_pipeline_set_color4ub (shadow->pipeline,
-                              opacity, opacity, opacity, opacity);
-
-  cogl_set_source (shadow->pipeline);
+  gboolean source_updated = FALSE;
 
   if (shadow->scale_width)
     {
@@ -300,6 +292,17 @@ meta_shadow_paint (MetaShadow     *shadow,
           else
             overlap = CAIRO_REGION_OVERLAP_IN;
 
+          if (overlap == CAIRO_REGION_OVERLAP_OUT)
+            continue;
+
+          if (!source_updated)
+            {
+              cogl_pipeline_set_color4ub (shadow->pipeline,
+                                          opacity, opacity, opacity, opacity);
+              cogl_set_source (shadow->pipeline);
+              source_updated = TRUE;
+            }
+
           /* There's quite a bit of overhead from allocating a new
            * region in order to find an exact intersection and
            * generating more geometry - we make the assumption that
@@ -309,10 +312,12 @@ meta_shadow_paint (MetaShadow     *shadow,
           if (overlap == CAIRO_REGION_OVERLAP_IN ||
               (overlap == CAIRO_REGION_OVERLAP_PART && !clip_strictly))
             {
-              cogl_rectangle_with_texture_coords (dest_x[i], dest_y[j],
-                                                  dest_x[i + 1], dest_y[j + 1],
-                                                  src_x[i], src_y[j],
-                                                  src_x[i + 1], src_y[j + 1]);
+              cogl_framebuffer_draw_textured_rectangle (framebuffer,
+                                                        shadow->pipeline,
+                                                        dest_x[i], dest_y[j],
+                                                        dest_x[i + 1], dest_y[j + 1],
+                                                        src_x[i], src_y[j],
+                                                        src_x[i + 1], src_y[j + 1]);
             }
           else if (overlap == CAIRO_REGION_OVERLAP_PART)
             {
@@ -343,9 +348,11 @@ meta_shadow_paint (MetaShadow     *shadow,
                   src_y2 = (src_y[j] * (dest_rect.y + dest_rect.height - (rect.y + rect.height)) +
                             src_y[j + 1] * (rect.y + rect.height - dest_rect.y)) / dest_rect.height;
 
-                  cogl_rectangle_with_texture_coords (rect.x, rect.y,
-                                                      rect.x + rect.width, rect.y + rect.height,
-                                                      src_x1, src_y1, src_x2, src_y2);
+                  cogl_framebuffer_draw_textured_rectangle (framebuffer,
+                                                            shadow->pipeline,
+                                                            rect.x, rect.y,
+                                                            rect.x + rect.width, rect.y + rect.height,
+                                                            src_x1, src_y1, src_x2, src_y2);
                 }
 
               cairo_region_destroy (intersection);
@@ -708,7 +715,7 @@ make_shadow (MetaShadow     *shadow,
 {
   ClutterBackend *backend = clutter_get_default_backend ();
   CoglContext *ctx = clutter_backend_get_cogl_context (backend);
-  CoglError *error = NULL;
+  GError *error = NULL;
   int d = get_box_filter_size (shadow->key.radius);
   int spread = get_shadow_spread (shadow->key.radius);
   cairo_rectangle_int_t extents;
@@ -811,7 +818,7 @@ make_shadow (MetaShadow     *shadow,
   if (error)
     {
       meta_warning ("Failed to allocate shadow texture: %s\n", error->message);
-      cogl_error_free (error);
+      g_error_free (error);
     }
 
   cairo_region_destroy (row_convolve_region);
