@@ -74,7 +74,8 @@ static gboolean meta_shaped_texture_get_paint_volume (ClutterActor *self, Clutte
 
 static void cullable_iface_init (MetaCullableInterface *iface);
 
-enum {
+enum
+{
   SIZE_CHANGED,
 
   LAST_SIGNAL,
@@ -315,6 +316,7 @@ get_base_pipeline (MetaShapedTexture *stex,
                    CoglContext       *ctx)
 {
   CoglPipeline *pipeline;
+  CoglMatrix matrix;
 
   if (stex->base_pipeline)
     return stex->base_pipeline;
@@ -328,11 +330,11 @@ get_base_pipeline (MetaShapedTexture *stex,
                                        COGL_PIPELINE_WRAP_MODE_CLAMP_TO_EDGE);
   cogl_pipeline_set_layer_wrap_mode_t (pipeline, 1,
                                        COGL_PIPELINE_WRAP_MODE_CLAMP_TO_EDGE);
+
+  cogl_matrix_init_identity (&matrix);
+
   if (!stex->is_y_inverted)
     {
-      CoglMatrix matrix;
-
-      cogl_matrix_init_identity (&matrix);
       cogl_matrix_scale (&matrix, 1, -1, 1);
       cogl_matrix_translate (&matrix, 0, -1, 0);
       cogl_pipeline_set_layer_matrix (pipeline, 0, &matrix);
@@ -340,10 +342,9 @@ get_base_pipeline (MetaShapedTexture *stex,
 
   if (stex->transform != META_MONITOR_TRANSFORM_NORMAL)
     {
-      CoglMatrix matrix;
       CoglEuler euler;
 
-      cogl_matrix_init_translation (&matrix, 0.5, 0.5, 0.0);
+      cogl_matrix_translate (&matrix, 0.5, 0.5, 0.0);
       switch (stex->transform)
         {
         case META_MONITOR_TRANSFORM_90:
@@ -372,11 +373,45 @@ get_base_pipeline (MetaShapedTexture *stex,
         }
       cogl_matrix_rotate_euler (&matrix, &euler);
       cogl_matrix_translate (&matrix, -0.5, -0.5, 0.0);
-
-      cogl_pipeline_set_layer_matrix (pipeline, 0, &matrix);
-      cogl_pipeline_set_layer_matrix (pipeline, 1, &matrix);
     }
 
+  if (stex->has_viewport_src_rect)
+    {
+      ClutterActor *actor = CLUTTER_ACTOR (stex);
+      double tex_scale;
+
+      clutter_actor_get_scale (actor, &tex_scale, NULL);
+
+      if (meta_monitor_transform_is_rotated (stex->transform))
+        {
+          cogl_matrix_scale (&matrix,
+                             stex->viewport_src_rect.size.width /
+                             (stex->tex_height * tex_scale),
+                             stex->viewport_src_rect.size.height /
+                             (stex->tex_width * tex_scale),
+                             1);
+        }
+      else
+        {
+          cogl_matrix_scale (&matrix,
+                             stex->viewport_src_rect.size.width /
+                             (stex->tex_width * tex_scale),
+                             stex->viewport_src_rect.size.height /
+                             (stex->tex_height * tex_scale),
+                             1);
+        }
+
+      cogl_matrix_translate (&matrix,
+                             stex->viewport_src_rect.origin.x /
+                             stex->viewport_src_rect.size.width,
+                             stex->viewport_src_rect.origin.y /
+                             stex->viewport_src_rect.size.height,
+                             0);
+    }
+
+  cogl_pipeline_set_layer_matrix (pipeline, 0, &matrix);
+  cogl_pipeline_set_layer_matrix (pipeline, 1, &matrix);
+
   if (stex->snippet)
     cogl_pipeline_add_layer_snippet (pipeline, 0, stex->snippet);
 
@@ -452,48 +487,10 @@ paint_clipped_rectangle (MetaShapedTexture     *stex,
   alloc_width = alloc->x2 - alloc->x1;
   alloc_height = alloc->y2 - alloc->y1;
 
-  if (stex->has_viewport_src_rect)
-    {
-      double tex_scale;
-      float src_x;
-      float src_y;
-      float src_width;
-      float src_height;
-
-      clutter_actor_get_scale (CLUTTER_ACTOR (stex), &tex_scale, NULL);
-
-      src_x = stex->viewport_src_rect.origin.x / tex_scale;
-      src_y = stex->viewport_src_rect.origin.y / tex_scale;
-      src_width = stex->viewport_src_rect.size.width / tex_scale;
-      src_height = stex->viewport_src_rect.size.height / tex_scale;
-
-      coords[0] = rect->x * src_width / alloc_width + src_x;
-      coords[1] = rect->y * src_height / alloc_height + src_y;
-      coords[2] = rect->width * src_width / alloc_width + coords[0];
-      coords[3] = rect->height * src_height / alloc_height + coords[1];
-
-      if (meta_monitor_transform_is_rotated (stex->transform))
-        {
-          coords[0] /= stex->tex_height;
-          coords[1] /= stex->tex_width;
-          coords[2] /= stex->tex_height;
-          coords[3] /= stex->tex_width;
-        }
-      else
-        {
-          coords[0] /= stex->tex_width;
-          coords[1] /= stex->tex_height;
-          coords[2] /= stex->tex_width;
-          coords[3] /= stex->tex_height;
-        }
-    }
-  else
-    {
-      coords[0] = rect->x / alloc_width;
-      coords[1] = rect->y / alloc_height;
-      coords[2] = (rect->x + rect->width) / alloc_width;
-      coords[3] = (rect->y + rect->height) / alloc_height;
-    }
+  coords[0] = rect->x / alloc_width;
+  coords[1] = rect->y / alloc_height;
+  coords[2] = (rect->x + rect->width) / alloc_width;
+  coords[3] = (rect->y + rect->height) / alloc_height;
 
   coords[4] = coords[0];
   coords[5] = coords[1];
@@ -760,11 +757,10 @@ do_paint (MetaShapedTexture *stex,
       else
         {
           /* 3) blended_tex_region is NULL. Do a full paint. */
-          paint_clipped_rectangle (stex,
-                                   fb,
-                                   blended_pipeline,
-                                   &tex_rect,
-                                   &alloc);
+          cogl_framebuffer_draw_rectangle (fb, blended_pipeline,
+                                           0, 0,
+                                           alloc.x2 - alloc.x1,
+                                           alloc.y2 - alloc.y1);
         }
     }
 
@@ -1206,6 +1202,7 @@ meta_shaped_texture_set_viewport_src_rect (MetaShapedTexture *stex,
     {
       stex->has_viewport_src_rect = TRUE;
       stex->viewport_src_rect = *src_rect;
+      meta_shaped_texture_reset_pipelines (stex);
       invalidate_size (stex);
     }
 }
@@ -1213,7 +1210,11 @@ meta_shaped_texture_set_viewport_src_rect (MetaShapedTexture *stex,
 void
 meta_shaped_texture_reset_viewport_src_rect (MetaShapedTexture *stex)
 {
+  if (!stex->has_viewport_src_rect)
+    return;
+
   stex->has_viewport_src_rect = FALSE;
+  meta_shaped_texture_reset_pipelines (stex);
   invalidate_size (stex);
 }
 
@@ -1236,6 +1237,9 @@ meta_shaped_texture_set_viewport_dst_size (MetaShapedTexture *stex,
 void
 meta_shaped_texture_reset_viewport_dst_size (MetaShapedTexture *stex)
 {
+  if (!stex->has_viewport_dst_size)
+    return;
+
   stex->has_viewport_dst_size = FALSE;
   invalidate_size (stex);
 }
@@ -1278,22 +1282,10 @@ get_image_via_offscreen (MetaShapedTexture     *stex,
   CoglOffscreen *offscreen;
   CoglFramebuffer *fb;
   CoglMatrix projection_matrix;
-  int fb_width, fb_height;
   cairo_rectangle_int_t fallback_clip;
   CoglColor clear_color;
   cairo_surface_t *surface;
 
-  if (cogl_has_feature (cogl_context, COGL_FEATURE_ID_TEXTURE_NPOT))
-    {
-      fb_width = stex->dst_width;
-      fb_height = stex->dst_height;
-    }
-  else
-    {
-      fb_width = _cogl_util_next_p2 (stex->dst_width);
-      fb_height = _cogl_util_next_p2 (stex->dst_height);
-    }
-
   if (!clip)
     {
       fallback_clip = (cairo_rectangle_int_t) {
@@ -1305,7 +1297,8 @@ get_image_via_offscreen (MetaShapedTexture     *stex,
 
   image_texture =
     COGL_TEXTURE (cogl_texture_2d_new_with_size (cogl_context,
-                                                 fb_width, fb_height));
+                                                 stex->dst_width,
+                                                 stex->dst_height));
   cogl_primitive_texture_set_auto_mipmap (COGL_PRIMITIVE_TEXTURE (image_texture),
                                           FALSE);
   if (!cogl_texture_allocate (COGL_TEXTURE (image_texture), &error))
@@ -1315,18 +1308,6 @@ get_image_via_offscreen (MetaShapedTexture     *stex,
       return FALSE;
     }
 
-  if (fb_width != stex->dst_width || fb_height != stex->dst_height)
-    {
-      CoglSubTexture *sub_texture;
-
-      sub_texture = cogl_sub_texture_new (cogl_context,
-                                          image_texture,
-                                          0, 0,
-                                          stex->dst_width, stex->dst_height);
-      cogl_object_unref (image_texture);
-      image_texture = COGL_TEXTURE (sub_texture);
-    }
-
   offscreen = cogl_offscreen_new_with_texture (COGL_TEXTURE (image_texture));
   fb = COGL_FRAMEBUFFER (offscreen);
   cogl_object_unref (image_texture);
