@@ -23,30 +23,48 @@
 #ifndef MUTTER_H_
 #define MUTTER_H_
 
-#include <clutter/clutter.h>
 #include <X11/Xlib.h>
 #include <X11/extensions/Xfixes.h>
 
-#include <meta/types.h>
-#include <meta/compositor.h>
-#include <meta/meta-window-actor.h>
+#include "clutter/clutter.h"
+#include "meta/compositor.h"
+#include "meta/meta-window-actor.h"
+#include "meta/types.h"
 
 /* Public compositor API */
+META_EXPORT
 ClutterActor *meta_get_stage_for_display            (MetaDisplay *display);
-Window        meta_get_overlay_window               (MetaDisplay *display);
+
+META_EXPORT
 GList        *meta_get_window_actors                (MetaDisplay *display);
+
+META_EXPORT
 ClutterActor *meta_get_window_group_for_display     (MetaDisplay *display);
+
+META_EXPORT
 ClutterActor *meta_get_top_window_group_for_display (MetaDisplay *display);
+
+META_EXPORT
 ClutterActor *meta_get_feedback_group_for_display   (MetaDisplay *display);
 
+META_EXPORT
 void meta_disable_unredirect_for_display (MetaDisplay *display);
+
+META_EXPORT
 void meta_enable_unredirect_for_display  (MetaDisplay *display);
 
+META_EXPORT
 void meta_set_stage_input_region   (MetaDisplay  *display,
                                     XserverRegion region);
+
+META_EXPORT
 void meta_empty_stage_input_region (MetaDisplay  *display);
+
+META_EXPORT
 void meta_focus_stage_window       (MetaDisplay  *display,
                                     guint32       timestamp);
+
+META_EXPORT
 gboolean meta_stage_is_focused     (MetaDisplay  *display);
 
 #endif
