@@ -207,6 +207,27 @@ meta_wayland_actor_surface_real_sync_actor_state (MetaWaylandActorSurface *actor
 
   meta_surface_actor_set_transform (surface_actor, surface->buffer_transform);
 
+  if (surface->viewport.has_src_rect)
+    {
+      meta_surface_actor_set_viewport_src_rect (surface_actor,
+                                                &surface->viewport.src_rect);
+    }
+  else
+    {
+      meta_surface_actor_reset_viewport_src_rect (surface_actor);
+    }
+
+  if (surface->viewport.has_dst_size)
+    {
+      meta_surface_actor_set_viewport_dst_size (surface_actor,
+                                                surface->viewport.dst_width,
+                                                surface->viewport.dst_height);
+    }
+  else
+    {
+      meta_surface_actor_reset_viewport_dst_size (surface_actor);
+    }
+
   for (l = surface->subsurfaces; l; l = l->next)
     {
       MetaWaylandSurface *subsurface_surface = l->data;
@@ -232,16 +253,9 @@ meta_wayland_actor_surface_commit (MetaWaylandSurfaceRole  *surface_role,
 {
   MetaWaylandActorSurface *actor_surface =
     META_WAYLAND_ACTOR_SURFACE (surface_role);
-  MetaWaylandSurface *surface =
-    meta_wayland_surface_role_get_surface (surface_role);
-  MetaWaylandSurface *toplevel_surface;
 
   meta_wayland_actor_surface_queue_frame_callbacks (actor_surface, pending);
 
-  toplevel_surface = meta_wayland_surface_get_toplevel (surface);
-  if (!toplevel_surface || !toplevel_surface->window)
-    return;
-
   meta_wayland_actor_surface_sync_actor_state (actor_surface);
 }
 
