@@ -36,7 +36,8 @@
 #include "xdg-output-unstable-v1-server-protocol.h"
 
 
-enum {
+enum
+{
   OUTPUT_DESTROYED,
 
   LAST_SIGNAL
@@ -572,7 +573,9 @@ send_xdg_output_events (struct wl_resource *resource,
   MetaRectangle new_layout;
   MetaRectangle old_layout;
   MetaLogicalMonitor *old_logical_monitor;
+  MetaMonitor *monitor;
   gboolean need_done;
+  int version;
 
   need_done = FALSE;
   old_logical_monitor = wayland_output->logical_monitor;
@@ -599,6 +602,25 @@ send_xdg_output_events (struct wl_resource *resource,
       need_done = TRUE;
     }
 
+  version = wl_resource_get_version (resource);
+  monitor = pick_main_monitor (logical_monitor);
+
+  if (need_all_events && version >= ZXDG_OUTPUT_V1_NAME_SINCE_VERSION)
+    {
+      const char *name;
+
+      name = meta_monitor_get_connector (monitor);
+      zxdg_output_v1_send_name (resource, name);
+    }
+
+  if (need_all_events && version >= ZXDG_OUTPUT_V1_DESCRIPTION_SINCE_VERSION)
+    {
+      const char *description;
+
+      description = meta_monitor_get_display_name (monitor);
+      zxdg_output_v1_send_description (resource, description);
+    }
+
   if (need_all_events)
     {
       zxdg_output_v1_send_done (resource);
@@ -623,14 +645,14 @@ meta_xdg_output_manager_get_xdg_output (struct wl_client   *client,
                                             wl_resource_get_version (resource),
                                             id);
 
-  wl_resource_set_implementation (xdg_output_resource,
-                                  &meta_xdg_output_interface,
-                                  NULL, meta_xdg_output_destructor);
-
   wayland_output = wl_resource_get_user_data (output);
   if (!wayland_output)
     return;
 
+  wl_resource_set_implementation (xdg_output_resource,
+                                  &meta_xdg_output_interface,
+                                  wayland_output, meta_xdg_output_destructor);
+
   wayland_output->xdg_output_resources =
     g_list_prepend (wayland_output->xdg_output_resources, xdg_output_resource);
 
