@@ -30,7 +30,6 @@
 
 #include "backends/meta-backend-private.h"
 #include "backends/meta-pointer-constraint.h"
-#include "backends/native/meta-backend-native.h"
 #include "core/frame.h"
 #include "core/window-private.h"
 #include "meta/meta-backend.h"
@@ -45,6 +44,10 @@
 
 #include "pointer-constraints-unstable-v1-server-protocol.h"
 
+#ifdef HAVE_NATIVE_BACKEND
+#include "backends/native/meta-backend-native.h"
+#endif
+
 static GQuark quark_pending_constraint_state = 0;
 static GQuark quark_surface_pointer_constraints_data = 0;
 
