@@ -30,7 +30,6 @@
 #include "backends/meta-cursor-tracker-private.h"
 #include "clutter/clutter.h"
 #include "clutter/wayland/clutter-wayland-compositor.h"
-#include "clutter/wayland/clutter-wayland-surface.h"
 #include "cogl/cogl-wayland-server.h"
 #include "compositor/meta-surface-actor-wayland.h"
 #include "compositor/meta-surface-actor.h"
@@ -57,7 +56,8 @@
 #include "wayland/meta-xwayland-private.h"
 #include "wayland/meta-xwayland-private.h"
 
-enum {
+enum
+{
   PENDING_STATE_SIGNAL_APPLIED,
 
   PENDING_STATE_SIGNAL_LAST_SIGNAL
@@ -87,7 +87,8 @@ G_DEFINE_TYPE (MetaWaylandPendingState,
                meta_wayland_pending_state,
                G_TYPE_OBJECT);
 
-enum {
+enum
+{
   SURFACE_DESTROY,
   SURFACE_UNMAPPED,
   SURFACE_CONFIGURE,
@@ -245,14 +246,9 @@ get_buffer_width (MetaWaylandSurface *surface)
   MetaWaylandBuffer *buffer = meta_wayland_surface_get_buffer (surface);
 
   if (buffer)
-    {
-      CoglTexture *texture = meta_wayland_buffer_get_texture (buffer);
-      return cogl_texture_get_width (texture);
-    }
+    return cogl_texture_get_width (surface->texture);
   else
-    {
-      return 0;
-    }
+    return 0;
 }
 
 static int
@@ -261,14 +257,9 @@ get_buffer_height (MetaWaylandSurface *surface)
   MetaWaylandBuffer *buffer = meta_wayland_surface_get_buffer (surface);
 
   if (buffer)
-    {
-      CoglTexture *texture = meta_wayland_buffer_get_texture (buffer);
-      return cogl_texture_get_height (texture);
-    }
+    return cogl_texture_get_height (surface->texture);
   else
-    {
-      return 0;
-    }
+    return 0;
 }
 
 static void
@@ -283,7 +274,7 @@ surface_process_damage (MetaWaylandSurface *surface,
   cairo_region_t *transformed_region;
   cairo_region_t *viewport_region;
   ClutterRect src_rect;
-  int i, n_rectangles;
+  MetaSurfaceActor *actor;
 
   /* If the client destroyed the buffer it attached before committing, but
    * still posted damage, or posted damage without any buffer, don't try to
@@ -342,21 +333,23 @@ surface_process_damage (MetaWaylandSurface *surface,
 
   cairo_region_intersect_rectangle (buffer_region, &buffer_rect);
 
-  /* First update the buffer. */
-  meta_wayland_buffer_process_damage (buffer, buffer_region);
+  meta_wayland_buffer_process_damage (buffer, surface->texture, buffer_region);
 
-  /* Now damage the actor. The actor expects damage in the unscaled texture
-   * coordinate space, i.e. same as the buffer. */
-  /* XXX: Should this be a signal / callback on MetaWaylandBuffer instead? */
-  n_rectangles = cairo_region_num_rectangles (buffer_region);
-  for (i = 0; i < n_rectangles; i++)
+  actor = meta_wayland_surface_get_actor (surface);
+  if (actor)
     {
-      cairo_rectangle_int_t rect;
-      cairo_region_get_rectangle (buffer_region, i, &rect);
+      int i, n_rectangles;
 
-      meta_surface_actor_process_damage (meta_wayland_surface_get_actor (surface),
-                                         rect.x, rect.y,
-                                         rect.width, rect.height);
+      n_rectangles = cairo_region_num_rectangles (buffer_region);
+      for (i = 0; i < n_rectangles; i++)
+        {
+          cairo_rectangle_int_t rect;
+          cairo_region_get_rectangle (buffer_region, i, &rect);
+
+          meta_surface_actor_process_damage (actor,
+                                             rect.x, rect.y,
+                                             rect.width, rect.height);
+        }
     }
 
   cairo_region_destroy (viewport_region);
@@ -690,8 +683,6 @@ meta_wayland_surface_apply_pending_state (MetaWaylandSurface      *surface,
 
   if (pending->newly_attached)
     {
-      gboolean switched_buffer;
-
       if (!surface->buffer_ref.buffer && surface->window)
         meta_window_queue (surface->window, META_QUEUE_CALC_SHOWING);
 
@@ -703,8 +694,7 @@ meta_wayland_surface_apply_pending_state (MetaWaylandSurface      *surface,
       if (surface->buffer_held)
         meta_wayland_surface_unref_buffer_use_count (surface);
 
-      switched_buffer = g_set_object (&surface->buffer_ref.buffer,
-                                      pending->buffer);
+      g_set_object (&surface->buffer_ref.buffer, pending->buffer);
 
       if (pending->buffer)
         meta_wayland_surface_ref_buffer_use_count (surface);
@@ -712,19 +702,23 @@ meta_wayland_surface_apply_pending_state (MetaWaylandSurface      *surface,
       if (pending->buffer)
         {
           GError *error = NULL;
+          gboolean changed_texture;
 
-          if (!meta_wayland_buffer_attach (pending->buffer, &error))
+          if (!meta_wayland_buffer_attach (pending->buffer,
+                                           &surface->texture,
+                                           &changed_texture,
+                                           &error))
             {
               g_warning ("Could not import pending buffer: %s", error->message);
               wl_resource_post_error (surface->resource, WL_DISPLAY_ERROR_NO_MEMORY,
-                                      "Failed to create a texture for surface %i: %s",
+                                      "Failed to attach buffer to surface %i: %s",
                                       wl_resource_get_id (surface->resource),
                                       error->message);
               g_error_free (error);
               goto cleanup;
             }
 
-          if (switched_buffer && meta_wayland_surface_get_actor (surface))
+          if (changed_texture && meta_wayland_surface_get_actor (surface))
             {
               MetaShapedTexture *stex;
               CoglTexture *texture;
@@ -732,7 +726,7 @@ meta_wayland_surface_apply_pending_state (MetaWaylandSurface      *surface,
               gboolean is_y_inverted;
 
               stex = meta_surface_actor_get_texture (meta_wayland_surface_get_actor (surface));
-              texture = meta_wayland_buffer_get_texture (pending->buffer);
+              texture = surface->texture;
               snippet = meta_wayland_buffer_create_snippet (pending->buffer);
               is_y_inverted = meta_wayland_buffer_is_y_inverted (pending->buffer);
 
@@ -742,6 +736,10 @@ meta_wayland_surface_apply_pending_state (MetaWaylandSurface      *surface,
               g_clear_pointer (&snippet, cogl_object_unref);
             }
         }
+      else
+        {
+          cogl_clear_object (&surface->texture);
+        }
 
       /* If the newly attached buffer is going to be accessed directly without
        * making a copy, such as an EGL buffer, mark it as in-use don't release
@@ -774,9 +772,8 @@ meta_wayland_surface_apply_pending_state (MetaWaylandSurface      *surface,
       surface->viewport.has_dst_size = surface->viewport.dst_width > 0;
     }
 
-  if (meta_wayland_surface_get_actor (surface) &&
-      (!cairo_region_is_empty (pending->surface_damage) ||
-       !cairo_region_is_empty (pending->buffer_damage)))
+  if (!cairo_region_is_empty (pending->surface_damage) ||
+      !cairo_region_is_empty (pending->buffer_damage))
     surface_process_damage (surface,
                             pending->surface_damage,
                             pending->buffer_damage);
@@ -1075,10 +1072,17 @@ wl_surface_set_buffer_scale (struct wl_client *client,
                              int scale)
 {
   MetaWaylandSurface *surface = wl_resource_get_user_data (resource);
-  if (scale > 0)
-    surface->pending->scale = scale;
-  else
-    g_warning ("Trying to set invalid buffer_scale of %d\n", scale);
+
+  if (scale <= 0)
+    {
+      wl_resource_post_error (resource,
+                              WL_SURFACE_ERROR_INVALID_SCALE,
+                              "Trying to set invalid buffer_scale of %d\n",
+                              scale);
+      return;
+    }
+
+  surface->pending->scale = scale;
 }
 
 static void
@@ -1327,6 +1331,7 @@ wl_surface_destructor (struct wl_resource *resource)
 
   if (surface->buffer_held)
     meta_wayland_surface_unref_buffer_use_count (surface);
+  g_clear_pointer (&surface->texture, cogl_object_unref);
   g_clear_object (&surface->buffer_ref.buffer);
 
   g_clear_object (&surface->pending);
@@ -1848,6 +1853,12 @@ meta_wayland_surface_is_shortcuts_inhibited (MetaWaylandSurface *surface,
   return g_hash_table_contains (surface->shortcut_inhibited_seats, seat);
 }
 
+CoglTexture *
+meta_wayland_surface_get_texture (MetaWaylandSurface *surface)
+{
+  return surface->texture;
+}
+
 MetaSurfaceActor *
 meta_wayland_surface_get_actor (MetaWaylandSurface *surface)
 {
