@@ -20,10 +20,10 @@
 #ifndef META_XWAYLAND_PRIVATE_H
 #define META_XWAYLAND_PRIVATE_H
 
-#include "meta-wayland-private.h"
-
 #include <glib.h>
 
+#include "wayland/meta-wayland-private.h"
+
 gboolean
 meta_xwayland_start (MetaXWaylandManager *manager,
                      struct wl_display   *display);
@@ -35,9 +35,9 @@ void
 meta_xwayland_stop (MetaXWaylandManager *manager);
 
 /* wl_data_device/X11 selection interoperation */
-void     meta_xwayland_init_selection         (void);
-void     meta_xwayland_shutdown_selection     (void);
-gboolean meta_xwayland_selection_handle_event (XEvent *xevent);
+void     meta_xwayland_init_dnd         (void);
+void     meta_xwayland_shutdown_dnd     (void);
+gboolean meta_xwayland_dnd_handle_event (XEvent *xevent);
 
 const MetaWaylandDragDestFuncs * meta_xwayland_selection_get_drag_dest_funcs (void);
 
